Export Package VRC : bc - bc B61M105cln
Update compared VRC:   B61Ma cn30
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
Creation Date      : 072017 14:28:19
Total file size    : 1292867
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
S = Subscription Templates
b = Functions
A = Additional Files
h = Help Text Codes
Q = SQL Queries
P = Customization Projects
----------------------
qbcttf00001                                           B61Ma35cln (not expired)
qbcttf00002                                           B61Ma15cln (not expired)
dbctfacp.otyp                                         B61Ma15cln (not expired)
dbctfgld.amnt                                         B61Ma15cln (not expired)
dbctfgld.date                                         B61Ma15cln (not expired)
dbctfgld.dbcr                                         B61Ma15cln (not expired)
dbctfgld.dimx                                         B61Ma15cln (not expired)
dbctfgld.docn                                         B61Ma15cln (not expired)
dbctfgld.leac                                         B61Ma15cln (not expired)
dbctfgld.lino                                         B61Ma15cln (not expired)
dbctfgld.prod                                         B61Ma15cln (not expired)
dbctfgld.serl                                         B61Ma15cln (not expired)
dbctfgld.srno                                         B61Ma15cln (not expired)
dbctfgld.ttyp                                         B61Ma15cln (not expired)
dbctfgld.year                                         B61Ma15cln (not expired)
dbcttc.generate                                       B61Ma15cln (not expired)
dbcttf.stat                                           B61Ma35cln (not expired)
tbcttf001                                             B61Ma15cln (not expired)
tbcttf020                                             B61Ma25cln (not expired)
tbcttf021                                             B61Ma25cln (not expired)
tbcttf022                                             B61Ma25cln (not expired)
tbcttf106                                             B61Ma35cln (not expired)
sbccor0235m000                                        B61Ma35cln (not expired)
sbccor0244m000                                        B61Ma75cln (not expired)
sbccor0247m000                                        B61Ma85cln (not expired)
sbccor0301m000                                        B61Ma85cln (not expired)
sbccor0302m000                                        B61Ma75cln (not expired)
sbcdmp0107m000                                        B61Ma85cln (not expired)
sbcttc0201m000                                        B61M105cln (not expired)
sbcttf0202m000                                        B61M105cln (not expired)
sbcttf0203m000                                        B61M105cln (not expired)
sbcttf0220m000                                        B61M105cln (not expired)
sbcttf0237m000                                        B61Ma15cln (not expired)
sbcttf0238m000                                        B61M105cln (not expired)
sbcttf1206m000                                        B61Ma35cln (not expired)
sbcttf1206m100                                        B61M105cln (not expired)
sbcttf2250m000                                        B61M105cln (not expired)
sbctti0201m000                                        B61M105cln (not expired)
sbcttt9200m000                                        B61Ma95cln (not expired)
sbctwh0201m000                                        B61Ma85cln (not expired)
pbccor0235                                            B61Ma35cln (without source) (not expired)
pbccor0244                                            B61Ma75cln (without source) (not expired)
pbccor0246                                            B61Ma75cln (without source) (not expired)
pbccor0247                                            B61Ma85cln (without source) (not expired)
pbccor0301                                            B61Ma85cln (without source) (not expired)
pbccor0302                                            B61Ma75cln (without source) (not expired)
pbcintdlltcfin                                        B61Ma25cln (without source) (not expired)
pbcttc0201                                            B61Ma55cln (without source) (not expired)
pbcttcdll0001                                         B61Ma25cln (without source) (not expired)
pbcttcdll0007                                         B61Ma15cln (without source) (not expired)
pbcttf0202                                            B61Ma75cln (without source) (not expired)
pbcttf0203                                            B61Ma85cln (without source) (not expired)
pbcttf0220                                            B61Ma75cln (without source) (not expired)
pbcttf0220a                                           B61Ma25cln (without source) (not expired)
pbcttf0237                                            B61Ma75cln (without source) (not expired)
pbcttf0238                                            B61Ma85cln (without source) (not expired)
pbcttf1206                                            B61Ma75cln (without source) (not expired)
pbcttf1206m100                                        B61Ma75cln (without source) (not expired)
pbcttf2250                                            B61Ma85cln (without source) (not expired)
pbcttfdll0001                                         B61Ma85cln (without source) (not expired)
pbcttfdll0004                                         B61M105cln (without source) (not expired)
pbcttfdll0006                                         B61Ma75cln (without source) (not expired)
pbcttfdll0007                                         B61Ma75cln (without source) (not expired)
pbcttfdll0008                                         B61Ma75cln (without source) (not expired)
pbcttfdll0202                                         B61Ma75cln (without source) (not expired)
pbcttfdll0238                                         B61M105cln (without source) (not expired)
pbctti0201                                            B61Ma25cln (without source) (not expired)
pbcttidll0001                                         B61M105cln (without source) (not expired)
pbcttt9200                                            B61Ma15cln (without source) (not expired)
pbcttt9201                                            B61Ma95cln (without source) (not expired)
pbctwh0201                                            B61Ma95cln (without source) (not expired)
pbctwhdll0001                                         B61Ma85cln (without source) (not expired)
fbccor0235m000d2                                      B61Ma35cln (not expired)
fbccor0244m000d2                                      B61Ma75cln (not expired)
fbccor0247m000d2                                      B61Ma85cln (not expired)
fbccor0301m000d2                                      B61Ma85cln (not expired)
fbccor0302m000d2                                      B61Ma75cln (not expired)
fbcdmp0107m000d2                                      B61Ma85cln (not expired)
fbcttc0201m000d2                                      B61M105cln (not expired)
fbcttf0202m000d2                                      B61M105cln (not expired)
fbcttf0203m000d2                                      B61M105cln (not expired)
fbcttf0220m000d2                                      B61M105cln (not expired)
fbcttf0237m000d2                                      B61Ma15cln (not expired)
fbcttf0238m000d2                                      B61M105cln (not expired)
fbcttf1206m000d2                                      B61Ma35cln (not expired)
fbcttf1206m100d2                                      B61M105cln (not expired)
fbcttf2250m000d2                                      B61M105cln (not expired)
fbctti0201m000d2                                      B61M105cln (not expired)
fbcttt9200m000d2                                      B61Ma95cln (not expired)
fbctwh0201m000d2                                      B61Ma85cln (not expired)
rbccor0235010002                                      B61Ma35cln (not expired)
rbccor0244110002                                      B61Ma75cln (not expired)
rbccor0247110002                                      B61Ma85cln (not expired)
rbccor0301110002                                      B61Ma85cln (not expired)
rbccor0302110002                                      B61Ma75cln (not expired)
rbcsqlinfor001 2                                      B61Ma85cln (not expired)
rbcsqljvdw03   2                                      B61Ma85cln (not expired)
rbcsqljvdwinr  2                                      B61Ma95cln (not expired)
rbcsqljvdwinr1 2                                      B61Ma95cln (not expired)
rbcsqljvdwinr2 2                                      B61Ma95cln (not expired)
rbcttc0201010002                                      B61Ma15cln (not expired)
rbcttc0201020002                                      B61Ma15cln (not expired)
rbcttcerrorrep 2                                      B61Ma15cln (not expired)
rbcttf0202110002                                      B61Ma15cln (not expired)
rbcttf0202120002                                      B61Ma15cln (not expired)
rbcttf0220110002                                      B61Ma25cln (not expired)
rbctti0201000012                                      B61M105cln (not expired)
rbctwh0201110002                                      B61Ma85cln (not expired)
cbcttc00001                                           B61Ma25cln (not expired)
cbcttc00002                                           B61Ma15cln (not expired)
cbcttc00003                                           B61Ma15cln (not expired)
cbcttc00004                                           B61Ma15cln (not expired)
cbcttc00005                                           B61Ma15cln (not expired)
cbcttc00006                                           B61Ma15cln (not expired)
cbcttc00007                                           B61Ma15cln (not expired)
cbcttc00008                                           B61Ma15cln (not expired)
cbcttc00009                                           B61Ma15cln (not expired)
cbcttc00010                                           B61Ma15cln (not expired)
cbcttc00011                                           B61Ma15cln (not expired)
cbcttc00012                                           B61Ma15cln (not expired)
cbcttc00013                                           B61Ma25cln (not expired)
cbcttf00005                                           B61Ma25cln (not expired)
cbcttf00006                                           B61Ma15cln (not expired)
cbcttf00007                                           B61Ma25cln (not expired)
cbcttf00008                                           B61Ma15cln (not expired)
cbcttf00009                                           B61Ma15cln (not expired)
cbcttf00010                                           B61Ma15cln (not expired)
cbcttf0202.01                                         B61Ma15cln (not expired)
cbcttf0202.02                                         B61Ma15cln (not expired)
cbcttf0202.03                                         B61Ma15cln (not expired)
cbcttf0202.04                                         B61Ma15cln (not expired)
cbcttf0202.05                                         B61Ma15cln (not expired)
cbcttf0202.06                                         B61Ma15cln (not expired)
cbcttf0202.07                                         B61Ma15cln (not expired)
cbcttf0202.08                                         B61Ma15cln (not expired)
cbcttf0202.09                                         B61Ma15cln (not expired)
cbcttf0202.10                                         B61Ma15cln (not expired)
cbcttf0202.11                                         B61Ma15cln (not expired)
cbcttf0202.12                                         B61Ma15cln (not expired)
cbcttf0202.13                                         B61Ma15cln (not expired)
cbcttf0238.01                                         B61Ma35cln (not expired)
cbcttf0238.02                                         B61Ma35cln (not expired)
cbcttf0238.03                                         B61Ma35cln (not expired)
cbcttf0238.04                                         B61Ma35cln (not expired)
cbcttf0238.05                                         B61Ma35cln (not expired)
cbcttf0238.06                                         B61Ma35cln (not expired)
cbcttf0238.07                                         B61Ma35cln (not expired)
cbcttf0238.08                                         B61Ma35cln (not expired)
cbcttf0238.09                                         B61Ma35cln (not expired)
cbcttfs0001                                           B61Ma15cln (not expired)
cbcttfs0002                                           B61Ma15cln (not expired)
cbcttfs0004                                           B61Ma15cln (not expired)
cbcttfs0007                                           B61Ma15cln (not expired)
cbcttfs0008                                           B61Ma15cln (not expired)
cbcttfs0009                                           B61Ma15cln (not expired)
cbcttfs0010                                           B61Ma15cln (not expired)
cbcttfs0011                                           B61Ma15cln (not expired)
cbcttfs0012                                           B61Ma15cln (not expired)
cbcttfs0014                                           B61Ma55cln (not expired)
cbctti0001.01                                         B61Ma15cln (not expired)
cbctti0001.02                                         B61Ma15cln (not expired)
cbcttis0001                                           B61Ma15cln (not expired)
cbcttis0002                                           B61Ma25cln (not expired)
cbcttis0003                                           B61Ma25cln (not expired)
cbcttt0001                                            B61Ma15cln (not expired)
bbcbic___slm___                                       B61M105cln (with source) (not expired)
obccor0235                                            B61Ma35cln
obccor0244                                            B61Ma75cln
obccor0246                                            B61Ma75cln
obccor0247                                            B61Ma85cln
obccor0301                                            B61Ma85cln
obccor0302                                            B61Ma75cln
obcintdlltcfin                                        B61Ma25cln
obcttc0201                                            B61Ma55cln
obcttcdll0001                                         B61Ma25cln
obcttcdll0007                                         B61Ma15cln
obcttf0202                                            B61Ma75cln
obcttf0203                                            B61Ma85cln
obcttf0220                                            B61Ma75cln
obcttf0220a                                           B61Ma25cln
obcttf0237                                            B61Ma75cln
obcttf0238                                            B61Ma85cln
obcttf1206                                            B61Ma75cln
obcttf1206m100                                        B61Ma75cln
obcttf2250                                            B61Ma85cln
obcttfdll0001                                         B61Ma85cln
obcttfdll0004                                         B61M105cln
obcttfdll0006                                         B61Ma75cln
obcttfdll0007                                         B61Ma75cln
obcttfdll0008                                         B61Ma75cln
obcttfdll0202                                         B61Ma75cln
obcttfdll0238                                         B61M105cln
obctti0201                                            B61Ma25cln
obcttidll0001                                         B61M105cln
obcttt9200                                            B61Ma15cln
obcttt9201                                            B61Ma95cln
obctwh0201                                            B61Ma95cln
obctwhdll0001                                         B61Ma85cln
obccor0235010002                                      B61Ma35cln
obccor0244110002                                      B61Ma75cln
obccor0247110002                                      B61Ma85cln
obccor0301110002                                      B61Ma85cln
obccor0302110002                                      B61Ma75cln
obcsqlinfor001 2                                      B61Ma85cln
obcsqljvdw03   2                                      B61Ma85cln
obcsqljvdwinr  2                                      B61Ma95cln
obcsqljvdwinr1 2                                      B61Ma95cln
obcsqljvdwinr2 2                                      B61Ma95cln
obcttc0201010002                                      B61Ma15cln
obcttc0201020002                                      B61Ma15cln
obcttcerrorrep 2                                      B61Ma15cln
obcttf0202110002                                      B61Ma15cln
obcttf0202120002                                      B61Ma15cln
obcttf0220110002                                      B61Ma25cln
obctti0201000012                                      B61M105cln
obctwh0201110002                                      B61Ma85cln
lbcbccor.mig.user   114                               B61Ma75cln (not expired)
lbcbccor0244.01     108                               B61Ma75cln (not expired)
lbcbccor0244.02     117                               B61Ma75cln (not expired)
lbcbccor0244.03     111                               B61Ma75cln (not expired)
lbcbccor0244.04     121                               B61Ma75cln (not expired)
lbcbccor0244.05     118                               B61Ma75cln (not expired)
lbcbcgen.selection  109                               B61Ma15cln (not expired)
lbcbcgen.shipment   108                               B61Ma75cln (not expired)
lbcbcgen.shipment.ln113                               B61Ma75cln (not expired)
lbcbcttc.error.mess 113                               B61Ma15cln (not expired)
lbcbcttc.index      113                               B61Ma15cln (not expired)
lbcbcttc.prim.key   121                               B61Ma15cln (not expired)
lbcbcttc.table      108                               B61Ma15cln (not expired)
lbcbcttc0200.01     111                               B61Ma25cln (not expired)
lbcbcttc0200.02     115                               B61Ma25cln (not expired)
lbcbcttc0201.01     106                               B61Ma15cln (not expired)
lbcbcttc0201.02     131                               B61Ma15cln (not expired)
lbcbcttc0201.03     119                               B61Ma15cln (not expired)
lbcbcttc0201.04     115                               B61Ma15cln (not expired)
lbcbcttc0201.05     123                               B61Ma15cln (not expired)
lbcbcttc0201.06     119                               B61Ma15cln (not expired)
lbcbcttc0201.12     145                               B61Ma15cln (not expired)
lbcbcttc0201.13     217                               B61Ma15cln (not expired)
lbcbcttc0201.14     212                               B61Ma15cln (not expired)
lbcbcttc0201.15     119                               B61Ma15cln (not expired)
lbcbcttf001.acce    108                               B61Ma15cln (not expired)
lbcbcttf001.accf    116                               B61Ma15cln (not expired)
lbcbcttf001.adtp    115                               B61Ma15cln (not expired)
lbcbcttf001.amnt    120                               B61Ma15cln (not expired)
lbcbcttf001.amth    123                               B61Ma15cln (not expired)
lbcbcttf001.bpid    116                               B61Ma15cln (not expired)
lbcbcttf001.ccty.f  107                               B61Ma15cln (not expired)
lbcbcttf001.ccur    120                               B61Ma15cln (not expired)
lbcbcttf001.core    121                               B61Ma15cln (not expired)
lbcbcttf001.corr    110                               B61Ma15cln (not expired)
lbcbcttf001.cprj.f  107                               B61Ma15cln (not expired)
lbcbcttf001.cust.f  108                               B61Ma15cln (not expired)
lbcbcttf001.cwar.f  109                               B61Ma15cln (not expired)
lbcbcttf001.dbcr    112                               B61Ma15cln (not expired)
lbcbcttf001.dim1    111                               B61Ma15cln (not expired)
lbcbcttf001.dim2    111                               B61Ma15cln (not expired)
lbcbcttf001.dim3    111                               B61Ma15cln (not expired)
lbcbcttf001.dim4    111                               B61Ma15cln (not expired)
lbcbcttf001.dim5    111                               B61Ma15cln (not expired)
lbcbcttf001.docn    108                               B61Ma15cln (not expired)
lbcbcttf001.docn    115                               B61Ma15cln (not expired)
lbcbcttf001.edes    117                               B61Ma15cln (not expired)
lbcbcttf001.erro    113                               B61Ma15cln (not expired)
lbcbcttf001.fcmp    117                               B61Ma15cln (not expired)
lbcbcttf001.fitr    121                               B61Ma15cln (not expired)
lbcbcttf001.guid    117                               B61Ma15cln (not expired)
lbcbcttf001.item.f  104                               B61Ma15cln (not expired)
lbcbcttf001.koor    113                               B61Ma15cln (not expired)
lbcbcttf001.leac    114                               B61Ma15cln (not expired)
lbcbcttf001.line    111                               B61Ma15cln (not expired)
lbcbcttf001.lino    104                               B61Ma15cln (not expired)
lbcbcttf001.lino    115                               B61Ma15cln (not expired)
lbcbcttf001.ocom    116                               B61Ma15cln (not expired)
lbcbcttf001.orno    112                               B61Ma15cln (not expired)
lbcbcttf001.pono    108                               B61Ma15cln (not expired)
lbcbcttf001.prin    107                               B61Ma15cln (not expired)
lbcbcttf001.proc    109                               B61Ma15cln (not expired)
lbcbcttf001.srno    126                               B61Ma15cln (not expired)
lbcbcttf001.tmpk    137                               B61Ma15cln (not expired)
lbcbcttf001.trdt    108                               B61Ma15cln (not expired)
lbcbcttf001.tror    118                               B61Ma15cln (not expired)
lbcbcttf002.amnt    106                               B61Ma15cln (not expired)
lbcbcttf002.amth    111                               B61Ma15cln (not expired)
lbcbcttf002.btno    112                               B61Ma15cln (not expired)
lbcbcttf002.ccur    108                               B61Ma15cln (not expired)
lbcbcttf002.cpcp    120                               B61Ma15cln (not expired)
lbcbcttf002.cprj.f  107                               B61Ma35cln (not expired)
lbcbcttf002.crdt    116                               B61Ma15cln (not expired)
lbcbcttf002.crus    110                               B61Ma15cln (not expired)
lbcbcttf002.cuni    104                               B61Ma15cln (not expired)
lbcbcttf002.dcdt    113                               B61Ma15cln (not expired)
lbcbcttf002.fper    113                               B61Ma15cln (not expired)
lbcbcttf002.fyer    111                               B61Ma15cln (not expired)
lbcbcttf002.nper    117                               B61Ma15cln (not expired)
lbcbcttf002.nuni    115                               B61Ma15cln (not expired)
lbcbcttf002.podt    112                               B61Ma15cln (not expired)
lbcbcttf002.pous    109                               B61Ma15cln (not expired)
lbcbcttf002.qty1    110                               B61Ma15cln (not expired)
lbcbcttf002.qty2    110                               B61Ma15cln (not expired)
lbcbcttf002.rate    113                               B61Ma15cln (not expired)
lbcbcttf002.ratf    111                               B61Ma15cln (not expired)
lbcbcttf002.refr    109                               B61Ma15cln (not expired)
lbcbcttf002.rper    116                               B61Ma15cln (not expired)
lbcbcttf002.ryer    114                               B61Ma15cln (not expired)
lbcbcttf002.vper    110                               B61Ma15cln (not expired)
lbcbcttf002.vyer    108                               B61Ma15cln (not expired)
lbcbcttf004.sern    108                               B61Ma15cln (not expired)
lbcbcttf006.dimx    109                               B61Ma15cln (not expired)
lbcbcttf006.mitm.f  109                               B61Ma15cln (not expired)
lbcbcttf006.supp.f  108                               B61Ma15cln (not expired)
lbcbcttf011.ttyp    116                               B61Ma15cln (not expired)
lbcbcttf020.crdt    113                               B61Ma25cln (not expired)
lbcbcttf020.docn    108                               B61Ma15cln (not expired)
lbcbcttf020.fitr    121                               B61Ma15cln (not expired)
lbcbcttf020.frot    107                               B61Ma25cln (not expired)
lbcbcttf020.koor    113                               B61Ma15cln (not expired)
lbcbcttf020.line    111                               B61Ma15cln (not expired)
lbcbcttf020.lino    104                               B61Ma15cln (not expired)
lbcbcttf020.ocom    116                               B61Ma15cln (not expired)
lbcbcttf020.orno    112                               B61Ma15cln (not expired)
lbcbcttf020.pono    108                               B61Ma15cln (not expired)
lbcbcttf020.prin    107                               B61Ma15cln (not expired)
lbcbcttf020.proc    109                               B61Ma15cln (not expired)
lbcbcttf020.trdt    108                               B61Ma15cln (not expired)
lbcbcttf020.tror    118                               B61Ma15cln (not expired)
lbcbcttf020.usgr    110                               B61Ma25cln (not expired)
lbcbcttf0202.09     207                               B61Ma15cln (not expired)
lbcbcttf0203.01     136                               B61Ma15cln (not expired)
lbcbcttf0203.valid  108                               B61Ma15cln (not expired)
lbcbcttf021.amnt    106                               B61Ma15cln (not expired)
lbcbcttf021.amth    111                               B61Ma15cln (not expired)
lbcbcttf021.btno    112                               B61Ma15cln (not expired)
lbcbcttf021.ccur    108                               B61Ma15cln (not expired)
lbcbcttf021.cpcp    120                               B61Ma15cln (not expired)
lbcbcttf021.crdt    116                               B61Ma15cln (not expired)
lbcbcttf021.crus    110                               B61Ma15cln (not expired)
lbcbcttf021.cuni    104                               B61Ma15cln (not expired)
lbcbcttf021.cwoc    110                               B61Ma25cln (not expired)
lbcbcttf021.dcdt    113                               B61Ma15cln (not expired)
lbcbcttf021.fper    113                               B61Ma15cln (not expired)
lbcbcttf021.fyer    111                               B61Ma15cln (not expired)
lbcbcttf021.nper    117                               B61Ma15cln (not expired)
lbcbcttf021.nuni    115                               B61Ma15cln (not expired)
lbcbcttf021.podt    112                               B61Ma15cln (not expired)
lbcbcttf021.pous    109                               B61Ma15cln (not expired)
lbcbcttf021.qty1    110                               B61Ma15cln (not expired)
lbcbcttf021.qty2    110                               B61Ma15cln (not expired)
lbcbcttf021.ratd    109                               B61Ma25cln (not expired)
lbcbcttf021.rate    113                               B61Ma15cln (not expired)
lbcbcttf021.ratf    111                               B61Ma15cln (not expired)
lbcbcttf021.refr    109                               B61Ma15cln (not expired)
lbcbcttf021.rper    116                               B61Ma15cln (not expired)
lbcbcttf021.rtyp    109                               B61Ma25cln (not expired)
lbcbcttf021.ryer    114                               B61Ma15cln (not expired)
lbcbcttf021.vper    110                               B61Ma15cln (not expired)
lbcbcttf021.vyer    108                               B61Ma15cln (not expired)
lbcbcttf022.amnt    106                               B61Ma25cln (not expired)
lbcbcttf022.amth    111                               B61Ma25cln (not expired)
lbcbcttf022.ccur    108                               B61Ma25cln (not expired)
lbcbcttf022.cpcp    120                               B61Ma25cln (not expired)
lbcbcttf022.cuni    104                               B61Ma25cln (not expired)
lbcbcttf022.cwoc    110                               B61Ma25cln (not expired)
lbcbcttf022.fper    113                               B61Ma25cln (not expired)
lbcbcttf022.fyer    111                               B61Ma25cln (not expired)
lbcbcttf022.nuni    115                               B61Ma25cln (not expired)
lbcbcttf022.ratd    109                               B61Ma25cln (not expired)
lbcbcttf022.rate    113                               B61Ma25cln (not expired)
lbcbcttf022.ratf    111                               B61Ma25cln (not expired)
lbcbcttf022.rper    116                               B61Ma25cln (not expired)
lbcbcttf022.rtyp    109                               B61Ma25cln (not expired)
lbcbcttf022.ryer    114                               B61Ma25cln (not expired)
lbcbcttf022.vper    110                               B61Ma25cln (not expired)
lbcbcttf022.vyer    108                               B61Ma25cln (not expired)
lbcbcttt9200.01     138                               B61Ma15cln (not expired)
lbcbcttt9200.02     115                               B61Ma15cln (not expired)
lbccisli.dino       208                               B61Ma15cln (not expired)
lbccisli.ortp       110                               B61Ma15cln (not expired)
lbccisli.seqn       104                               B61Ma15cln (not expired)
lbccisli.slcp       308                               B61Ma15cln (not expired)
lbccisli.slso       309                               B61Ma15cln (not expired)
lbccisli240.oset    103                               B61Ma15cln (not expired)
lbccisli245.boid    209                               B61Ma15cln (not expired)
lbccisli245.borf    125                               B61Ma15cln (not expired)
lbccnv.total.order  115                               B61Ma15cln (not expired)
lbccor023501000001  135                               B61Ma35cln (not expired)
lbccor0235m000002   135                               B61Ma35cln (not expired)
lbccor0235m000003   135                               B61Ma35cln (not expired)
lbccor0235m000004   135                               B61Ma35cln (not expired)
lbccor024411000001  148                               B61Ma75cln (not expired)
lbccor0244m000002   148                               B61Ma75cln (not expired)
lbccor024711000001  150                               B61Ma85cln (not expired)
lbccor02471100002   150                               B61Ma85cln (not expired)
lbccor0247m000001   150                               B61Ma85cln (not expired)
lbccor030111000001  137                               B61Ma85cln (not expired)
lbccor0301m000001   137                               B61Ma85cln (not expired)
lbccor030211000001  130                               B61Ma75cln (not expired)
lbccor0302m000001   129                               B61Ma75cln (not expired)
lbcgen.options      107                               B61Ma75cln (not expired)
lbcgen.peg.line     108                               B61Ma95cln (not expired)
lbcgen.rcpt.line    112                               B61M105cln (not expired)
lbcinh.cpro         118                               B61Ma85cln (not expired)
lbcowner            105                               B61Ma95cln (not expired)
lbcownership        109                               B61Ma95cln (not expired)
lbcprod.order       116                               B61Ma75cln (not expired)
lbcprod.order       215                               B61Ma15cln (not expired)
lbcserialnumber     113                               B61Ma15cln (not expired)
lbcseries           106                               B61Ma15cln (not expired)
lbcsfc000.absh      124                               B61Ma15cln (not expired)
lbcsfc000.inab      163                               B61Ma15cln (not expired)
lbcsfc000.serg      135                               B61Ma15cln (not expired)
lbcsimulate         130                               B61Ma85cln (not expired)
lbctccom120.otbp    102                               B61Ma95cln (not expired)
lbctcgen.item       104                               B61Ma95cln (not expired)
lbctcgen.login      104                               B61Ma95cln (not expired)
lbctcgen.obsolete   108                               B61Ma95cln (not expired)
lbctcgen.reference  109                               B61Ma85cln (not expired)
lbctcgen.seqno      108                               B61Ma95cln (not expired)
lbctcgen.ship       108                               B61Ma95cln (not expired)
lbctcgen.weight     106                               B61Ma85cln (not expired)
lbctcmcs003.cwar    109                               B61Ma85cln (not expired)
lbctcmcs052.cprj    107                               B61Ma95cln (not expired)
lbctcmcs066.chan    107                               B61Ma95cln (not expired)
lbctdgen.activity   108                               B61Ma85cln (not expired)
lbctfacp.otyp009    108                               B61Ma15cln (not expired)
lbctfacp.otyp010    105                               B61Ma15cln (not expired)
lbctfacp.otyp012    108                               B61Ma15cln (not expired)
lbctfacp.otyp013    117                               B61Ma15cln (not expired)
lbctfacp.otyp014    112                               B61Ma15cln (not expired)
lbctfgld.dbcr003    106                               B61Ma15cln (not expired)
lbctfgld.dbcr004    105                               B61Ma15cln (not expired)
lbcttc.field1       107                               B61Ma15cln (not expired)
lbcttc.field2       107                               B61Ma15cln (not expired)
lbcttc.generate001  106                               B61Ma15cln (not expired)
lbcttc.generate002  110                               B61Ma15cln (not expired)
lbcttc.generate003  110                               B61Ma15cln (not expired)
lbcttc.key          103                               B61Ma15cln (not expired)
lbcttc.key.desc     115                               B61Ma15cln (not expired)
lbcttc000000001001  115                               B61Ma15cln (not expired)
lbcttc000000011002  111                               B61Ma25cln (not expired)
lbcttc000000021002  115                               B61Ma25cln (not expired)
lbcttc000010011002  118                               B61Ma25cln (not expired)
lbcttc000010021001  128                               B61Ma25cln (not expired)
lbcttc000010031002  131                               B61Ma25cln (not expired)
lbcttc000010041001  119                               B61Ma25cln (not expired)
lbcttc000010051001  119                               B61Ma25cln (not expired)
lbcttc000010061001  125                               B61Ma75cln (not expired)
lbcttc000020011002  122                               B61Ma25cln (not expired)
lbcttc000020021001  123                               B61Ma25cln (not expired)
lbcttc000020031001  133                               B61Ma25cln (not expired)
lbcttc000020041001  129                               B61Ma25cln (not expired)
lbcttc000020051001  123                               B61Ma25cln (not expired)
lbcttc000020061001  123                               B61Ma25cln (not expired)
lbcttc000020071001  135                               B61Ma25cln (not expired)
lbcttc000020081001  127                               B61Ma85cln (not expired)
lbcttc0201.01       112                               B61Ma15cln (not expired)
lbcttc0201.02       103                               B61Ma15cln (not expired)
lbcttc0201.02       109                               B61Ma15cln (not expired)
lbcttc0201.03       103                               B61Ma15cln (not expired)
lbcttc0201.03       109                               B61Ma15cln (not expired)
lbcttc020101000001  129                               B61Ma15cln (not expired)
lbcttc020102000001  130                               B61Ma15cln (not expired)
lbcttc0201m000001   123                               B61Ma15cln (not expired)
lbcttc100000001001  125                               B61Ma85cln (not expired)
lbcttc100000011001  130                               B61Ma85cln (not expired)
lbcttcmigratio1001  123                               B61Ma15cln (not expired)
lbcttf.bal.acc      165                               B61Ma15cln (not expired)
lbcttf.closed       106                               B61Ma15cln (not expired)
lbcttf.open         104                               B61Ma15cln (not expired)
lbcttf.opening.bal  168                               B61Ma15cln (not expired)
lbcttf.periods      107                               B61Ma15cln (not expired)
lbcttf.stat001      104                               B61Ma35cln (not expired)
lbcttf.stat002      110                               B61Ma35cln (not expired)
lbcttf.stat003      105                               B61Ma35cln (not expired)
lbcttf000010011001  110                               B61Ma25cln (not expired)
lbcttf001001        127                               B61Ma15cln (not expired)
lbcttf001002        137                               B61Ma15cln (not expired)
lbcttf00101002      136                               B61Ma15cln (not expired)
lbcttf002002        124                               B61Ma15cln (not expired)
lbcttf003002        146                               B61Ma15cln (not expired)
lbcttf020002        137                               B61Ma15cln (not expired)
lbcttf02001002      134                               B61Ma25cln (not expired)
lbcttf02002002      140                               B61Ma25cln (not expired)
lbcttf0202.01       113                               B61Ma15cln (not expired)
lbcttf0202.02       108                               B61Ma15cln (not expired)
lbcttf0202.03       114                               B61Ma15cln (not expired)
lbcttf0202.04       112                               B61Ma15cln (not expired)
lbcttf0202.05       115                               B61Ma15cln (not expired)
lbcttf0202.06       118                               B61Ma15cln (not expired)
lbcttf0202.07       209                               B61Ma15cln (not expired)
lbcttf0202.08       208                               B61Ma15cln (not expired)
lbcttf0202.10       206                               B61Ma15cln (not expired)
lbcttf0202.11       213                               B61Ma15cln (not expired)
lbcttf0202.12       107                               B61Ma15cln (not expired)
lbcttf0202.12       114                               B61Ma15cln (not expired)
lbcttf020211000001  149                               B61Ma15cln (not expired)
lbcttf020212000001  147                               B61Ma15cln (not expired)
lbcttf0202m000001   132                               B61Ma15cln (not expired)
lbcttf0203.continue 108                               B61Ma15cln (not expired)
lbcttf0203001       136                               B61Ma15cln (not expired)
lbcttf0203m000001   136                               B61Ma15cln (not expired)
lbcttf021002        123                               B61Ma25cln (not expired)
lbcttf02101002      128                               B61Ma25cln (not expired)
lbcttf022002        146                               B61Ma15cln (not expired)
lbcttf022003        124                               B61Ma25cln (not expired)
lbcttf02201002      128                               B61Ma25cln (not expired)
lbcttf0220m000001   132                               B61Ma15cln (not expired)
lbcttf0237m000001   165                               B61Ma15cln (not expired)
lbcttf0238.01       110                               B61Ma35cln (not expired)
lbcttf0238.02       116                               B61Ma35cln (not expired)
lbcttf0238m000001   133                               B61Ma35cln (not expired)
lbcttf100000001001  110                               B61Ma25cln (not expired)
lbcttf106.01        126                               B61Ma35cln (not expired)
lbcttf106.03        107                               B61Ma35cln (not expired)
lbcttf106002        144                               B61Ma35cln (not expired)
lbcttf10601001      116                               B61Ma35cln (not expired)
lbcttf10602001      124                               B61Ma35cln (not expired)
lbcttf1206.01       110                               B61Ma15cln (not expired)
lbcttf1206.02       111                               B61Ma15cln (not expired)
lbcttf1206m000001   153                               B61Ma15cln (not expired)
lbcttf1206m100001   148                               B61Ma35cln (not expired)
lbcttf1206m100002   148                               B61Ma35cln (not expired)
lbcttf2250m000002   127                               B61Ma55cln (not expired)
lbcttfs0203.01      117                               B61Ma15cln (not expired)
lbcttfs0203.02      142                               B61Ma85cln (not expired)
lbctti.ex.serno     134                               B61Ma15cln (not expired)
lbctti020100001001  144                               B61Ma15cln (not expired)
lbctti0201m000001   124                               B61Ma25cln (not expired)
lbcttt9200m000001   119                               B61Ma15cln (not expired)
lbctwh000010011001  122                               B61Ma85cln (not expired)
lbctwh020111000001  136                               B61Ma85cln (not expired)
lbctwh0201m000002   136                               B61Ma85cln (not expired)
lbcwh.clot          103                               B61Ma95cln (not expired)
lbcwhgen.boml       108                               B61Ma95cln (not expired)
lbcwhgen.date       116                               B61Ma85cln (not expired)
lbcwhgen.ext.hu     122                               B61Ma85cln (not expired)
lbcwhgen.h.unit     113                               B61Ma85cln (not expired)
lbcwhgen.inspection 110                               B61Ma85cln (not expired)
lbcwhgen.line       104                               B61Ma85cln (not expired)
lbcwhgen.load       104                               B61Ma85cln (not expired)
lbcwhgen.on.hold    107                               B61Ma85cln (not expired)
lbcwhgen.pack.slip  112                               B61Ma85cln (not expired)
lbcwhgen.qty.reject 112                               B61Ma85cln (not expired)
lbcwhgen.reason     106                               B61Ma85cln (not expired)
lbcwhgen.receipt    107                               B61M105cln (not expired)
lbcwhgen.shipment   108                               B61Ma85cln (not expired)
lbcwhgen.valuation  116                               B61Ma95cln (not expired)
lbcwhinh200.oorg    112                               B61Ma85cln (not expired)
lbcwhinh200.orno    105                               B61Ma95cln (not expired)
lbcwhinh200.oset    103                               B61Ma85cln (not expired)
lbcwhinh210.mpnr    124                               B61Ma85cln (not expired)
lbcwhinh210.qput    108                               B61Ma85cln (not expired)
lbcwhinh211.qdes    109                               B61Ma85cln (not expired)
lbcwhinh211.strj    108                               B61Ma95cln (not expired)
lbcwhinh212.cact    108                               B61Ma95cln (not expired)
lbcwhinh212.ccco    108                               B61Ma95cln (not expired)
lbcwhinh212.cspa    107                               B61Ma95cln (not expired)
lbcwhinh212.cstl    109                               B61Ma95cln (not expired)
lbcwhinh215.acti    108                               B61Ma85cln (not expired)
lbcwhinh215.pmsk    114                               B61Ma85cln (not expired)
lbcwhinh300.shdt    113                               B61Ma85cln (not expired)
lbcwhinh312.cmpl    108                               B61Ma85cln (not expired)
lbcwhinh312.conf    109                               B61Ma85cln (not expired)
lbcwhinh312.dmse    113                               B61Ma85cln (not expired)
lbcwhinh312.lsta    111                               B61Ma85cln (not expired)
lbcwhinh312.qapr    108                               B61Ma85cln (not expired)
lbcwhinh430.shpm    108                               B61Ma85cln (not expired)
lbcwhinh431.ilgd    116                               B61Ma95cln (not expired)
lbcwhinh431.invd    112                               B61Ma95cln (not expired)
lbcwhinr100.koor    110                               B61Ma95cln (not expired)
lbcwhinr100.kost    116                               B61Ma95cln (not expired)
lbcwhinr100.trdt    116                               B61Ma85cln (not expired)
lbcwhinr110.lgdt    115                               B61Ma95cln (not expired)
lbcwhinr140.idat    114                               B61Ma85cln (not expired)
lbcwhltc100.clot    103                               B61Ma85cln (not expired)
lbcwhltc100.effn    109                               B61Ma85cln (not expired)
lbcwhltc100.ltbp    127                               B61Ma85cln (not expired)
lbcwhltc100.revi    108                               B61Ma85cln (not expired)
lbcwhltc500.serl    113                               B61Ma95cln (not expired)
lbcwhwmd200.cwar    109                               B61Ma85cln (not expired)
lbcwhwmd410.pkdf    108                               B61Ma85cln (not expired)
lbcwmd.specification113                               B61Ma95cln (not expired)
Fbccor0235m000d2                                      B61Ma35cln
Fbccor0244m000d2                                      B61Ma75cln
Fbccor0247m000d2                                      B61Ma85cln
Fbccor0301m000d2                                      B61Ma85cln
Fbccor0302m000d2                                      B61Ma75cln
Fbcdmp0107m000d2                                      B61Ma85cln
Fbcttc0201m000d2                                      B61M105cln
Fbcttf0202m000d2                                      B61M105cln
Fbcttf0203m000d2                                      B61M105cln
Fbcttf0220m000d2                                      B61M105cln
Fbcttf0237m000d2                                      B61Ma15cln
Fbcttf0238m000d2                                      B61M105cln
Fbcttf1206m000d2                                      B61Ma35cln
Fbcttf1206m100d2                                      B61M105cln
Fbcttf2250m000d2                                      B61M105cln
Fbctti0201m000d2                                      B61M105cln
Fbcttt9200m000d2                                      B61Ma95cln
Fbctwh0201m000d2                                      B61Ma85cln
Mbcgctmigratio12                                      B61Ma65cln
Mbcgctparam   12                                      B61Ma65cln
Mbcgctpreconv 12                                      B61Ma65cln
Mbcttc0000000012                                      B61Ma75cln
Mbcttc0000000112                                      B61Ma75cln
Mbcttc0000000212                                      B61Ma85cln
Mbcttc0000100112                                      B61Ma85cln
Mbcttc0000100212                                      B61Ma65cln
Mbcttc0000100312                                      B61Ma65cln
Mbcttc0000100412                                      B61Ma65cln
Mbcttc0000100512                                      B61Ma85cln
Mbcttc0000100612                                      B61Ma85cln
Mbcttc0000200112                                      B61Ma65cln
Mbcttc0000200212                                      B61Ma95cln
Mbcttc0000200312                                      B61Ma65cln
Mbcttc0000200412                                      B61Ma65cln
Mbcttc0000200512                                      B61Ma65cln
Mbcttc0000200612                                      B61Ma85cln
Mbcttc0000200712                                      B61Ma65cln
Mbcttc0000200812                                      B61M105cln
Mbcttc1000000012                                      B61Ma85cln
Mbcttc1000000112                                      B61Ma85cln
Mbcttcmigratio12                                      B61Ma65cln
